@@ -5,6 +5,7 @@ import (
 	"bufio"
 	"bytes"
 	"context"
+	"errors"
 	"fmt"
 	"io"
 	"io/ioutil"
@@ -275,6 +276,26 @@ func GetHostInfo(ctx context.Context) (info types.Info, err error) {
 	return info, nil
 }
 
+// Arch fetches values from docker info and translates architecture to
+// GitHub actions compatible runner.arch values
+// https://github.com/github/docs/blob/main/data/reusables/actions/runner-arch-description.md
+func RunnerArch(ctx context.Context) string {
+	info, err := GetHostInfo(ctx)
+	if err != nil {
+		return ""
+	}
+
+	archMapper := map[string]string{
+		"x86_64":  "X64",
+		"386":     "x86",
+		"aarch64": "arm64",
+	}
+	if arch, ok := archMapper[info.Architecture]; ok {
+		return arch
+	}
+	return info.Architecture
+}
+
 func (cr *containerReference) connect() common.Executor {
 	return func(ctx context.Context) error {
 		if cr.cli != nil {
@@ -696,7 +717,7 @@ func (cr *containerReference) copyDir(dstPath string, srcPath string, useGitIgno
 		defer func(tarFile *os.File) {
 			name := tarFile.Name()
 			err := tarFile.Close()
-			if err != nil {
+			if !errors.Is(err, os.ErrClosed) {
 				logger.Error(err)
 			}
 			err = os.Remove(name)
